	
function UpdateScreen() {
	// Get the update button element and assign an 'onclick' event to it.
	var self = this;
	var updateButton = document.getElementById( "update_status_button" );
	updateButton.onclick = function() {
		 self.onUpdateClicked();
	};
	
	// Also update the remaining characters label on text changes.
	this.taStatus = document.getElementById( "status_message" );
	this.taStatus.onkeydown = function() { self.onStatusMessageChanged(); };
	this.taStatus.onkeyup = function() { self.onStatusMessageChanged(); };
	this.taStatus.onblur = function() { self.onStatusMessageChanged(); };

	this.lblCharsRemaining = document.getElementById( "status_chars" );
	this.lblCharsRemaining.innerHTML = UpdateScreen.MAX_STATUS_LENGTH;
}

UpdateScreen.prototype.onStatusMessageChanged = function() {
	// Calculate how many chars there are left and update the label.
	// Also prevent the user inputting too many characters.
	if( this.taStatus.value.length > UpdateScreen.MAX_STATUS_LENGTH ) {
		this.taStatus.value = this.taStatus.value.substring( 0, UpdateScreen.MAX_STATUS_LENGTH );
	} else {
		this.lblCharsRemaining.innerHTML = UpdateScreen.MAX_STATUS_LENGTH - this.taStatus.value.length;
	}
}

UpdateScreen.prototype.setMyLatestStatus = function( status, time ) {
	// Get the element and format the propper HTML.
	var statusTd = document.getElementById( "latest_status" );
	statusTd.innerHTML = "<span class='latest'>" + StringTable.Code.updateScreenLatest + ": </span>" + status + "<div class='ago'>" + time + "</div>";
}

UpdateScreen.prototype.onActivated = function() {
	// Add event listeners.
	var self = this;
	twitterService.onSuccess = function( response ) { self.onTwitterUserResponse( response ) }
	twitterService.onError = function( status ) { self.onTwitterServiceError( status ) }

	// Start the request.
	twitterService.getTweetsForUser( null, 1 );
}

UpdateScreen.prototype.onTwitterUserResponse = function( response ) {
	// Set my latest status update.
	var tweet = response[0];
	var tdate = new Date( tweet.created_at );
	this.setMyLatestStatus( tweet.text, tdate.toLocaleDateString() + " " + tdate.toLocaleTimeString() );

	// Now do a subsequent request to get firend's tweets.
	// Set a new listener for successful response and leave error handler as is.
	var self = this;
	twitterService.onSuccess = function( response ) { self.onTwitterFriendsResponse( response ) }

	// Start the request.
	twitterService.getFriendsTweets( 10 );
}

UpdateScreen.prototype.onTwitterFriendsResponse = function( response ) {
	var tweetsTable = document.getElementById( "update_tweets_table" );
	var html = Helper.createTableHeader( StringTable.Code.updateScreenCaption );

	// Fill in the table.
	for ( var i = 0; i < response.length; ++i ) {
		var tweet = response[i];
		
		var tdate = new Date( tweet.created_at );
	
		html += Helper.createStatusRow( tweet.user.profile_image_url,
			tweet.user.screen_name,
			tweet.text,
			tdate.toLocaleDateString() + " " + tdate.toLocaleTimeString(),
			StringTable.Code.updateScreenFrom + " " + tweet.source );			
	}
	
	tweetsTable.innerHTML = html;
}

UpdateScreen.prototype.onUpdateClicked = function() {
	// Add event listeners.
	var self = this;
	twitterService.onSuccess = function( response ) { self.onTwitterStatusUpdated( response ) }

	// Start the request.
	twitterService.updateStatus( this.taStatus.value );
}

UpdateScreen.prototype.onTwitterStatusUpdated = function( status ) {
	this.setMyLatestStatus( this.taStatus.value, StringTable.Code.updateScreenNow );
}

UpdateScreen.prototype.onTwitterServiceError = function( status ) {
	// Alert the user that something has gone wrong.
	alert( StringTable.Code.updateScreenDataError + " (" + status + ")" );
}



UpdateScreen.MAX_STATUS_LENGTH = 140;
